@@ -6,6 +6,9 @@ import os
 def DebugLog(msg):
    if os.environ.has_key('DEBUG'):
       print str(msg)
-   # f = open('/home/user/debug.txt', 'a')
-   # f.write(msg+"\n")
-   # f.close()
+
+def DebugFile(msg):
+   if os.environ.has_key('DEBUG'):
+      f = open('debug.log', 'a')
+      f.write(str(msg)+"\n")
+      f.close()
