@@ -71,11 +71,15 @@ class QonsoModel:
    ## 
    # Remplit les données pour la consommation voix
    # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
-   def SetConsoVoix(self, s, invert=False):
-      self.voix['int'], self.voix['str'] = self.ExtractTime(s)
-      if invert:
-         self.voix['int'] = self.voixMax['int']-self.voix['int']
-         self.voix['str'] = self.TimeStrFromInt(self.voix['int'])
+   def SetConsoVoix(self, s, invert=False, euro=False):
+      if euro:
+         self.voix['int'] = float(s)
+         self.voix['str'] = str(s)+'&euro;'
+      else:
+         self.voix['int'], self.voix['str'] = self.ExtractTime(s)
+         if invert:
+            self.voix['int'] = self.voixMax['int']-self.voix['int']
+            self.voix['str'] = self.TimeStrFromInt(self.voix['int'])
    
    ##
    # Renvoit la consommation voix, en fonction du type
@@ -125,7 +129,11 @@ class QonsoModel:
    # Remplit la durée du forfait pour la consommation voix
    # @param s  string contenant les données au format [hh]h[mm] (ex : 2h 30)
    def SetConsoVoixMax(self, s):
-      self.voixMax['int'], self.voixMax['str'] = self.ExtractTime(s)
+      if s==None:
+         self.voixMax['int'] = None
+         self.voixMax['str'] = None
+      else:
+         self.voixMax['int'], self.voixMax['str'] = self.ExtractTime(s)
 
    ##
    # Renvoit la durée du forfait pour la consommation voix, en fonction du type
@@ -201,7 +209,10 @@ class QonsoModel:
    # Replit le montant de la consommation hors forfait 
    # @param hforfait  int
    def SetConsoHorsForfait(self, hforfait):
-      self.hforfait = str(hforfait)+" &euro;"
+      if hforfait==None:
+         self.hforfait = None
+      else:
+         self.hforfait = str(hforfait)+" &euro;"
 
    ##
    # Renvoit le montant de la consommation hors forfait
@@ -211,6 +222,9 @@ class QonsoModel:
 
    def GetDateProchaineFacture(self):
       return self.facture 
+
+   def SetDateProchaineFacture(self, s):
+      self.facture = s
       
    ## 
    # Remplit la durée des minutes reportées
